@@ -57,35 +57,39 @@ class EnvironmentError(Exception):
 class EnvironmentEvent(Event):
     """Environment Event"""
 
-    _target = "env"
+    channels = ("env",)
+
+
+class Ready(EnvironmentEvent):
+    """Ready Environment Event"""
 
 
 class Create(EnvironmentEvent):
     """Create Environment Event"""
 
-    success = "create_success", EnvironmentEvent._target
-    failure = "create_failure", EnvironmentEvent._target
+    success = True
+    failure = True
 
 
 class Load(EnvironmentEvent):
     """Load Environment Event"""
 
-    success = "load_success", EnvironmentEvent._target
-    failure = "load_failure", EnvironmentEvent._target
+    success = True
+    failure = True
 
 
 class Verify(EnvironmentEvent):
     """Verify Environment Event"""
 
-    success = "verify_success", EnvironmentEvent._target
-    failure = "verify_failure", EnvironmentEvent._target
+    success = True
+    failure = True
 
 
 class Upgrade(EnvironmentEvent):
     """Upgrade Environment Event"""
 
-    success = "upgrade_success", EnvironmentEvent._target
-    failure = "upgrade_failure", EnvironmentEvent._target
+    success = True
+    failure = True
 
 
 class Environment(BaseComponent):
@@ -115,7 +119,7 @@ class Environment(BaseComponent):
     @handler("load", priority=1.0)
     def load(self, verify=False):
         if verify:
-            return self.push(Verify())
+            return self.fire(Verify())
         else:
             return self._load()
 
@@ -132,11 +136,11 @@ class Environment(BaseComponent):
                 raise EnvironmentError(*ERRORS[1])
 
     @handler("verify_success", filter=True)
-    def _on_verify_success(self, evt, handler, retval):
+    def _on_verify_success(self, evt, retval):
         return self._load()
 
-    @handler("load_success", target="config")
-    def _on_config_load_success(self, evt, handler, retval):
+    @handler("load_success", channel="config")
+    def _on_config_load_success(self, evt, retval):
         # Create Logger Component
         logname = self.envname
         logtype = self.config.get("logging", "type", "file")
@@ -146,6 +150,7 @@ class Environment(BaseComponent):
         if not isabs(logfile):
             logfile = joinpath(self.path, logfile)
         self.log = Logger(logfile, logname, logtype, loglevel).register(self)
+        self.fire(Ready())
 
     def _create(self):
         # Create the directory structure
@@ -174,11 +179,11 @@ class Environment(BaseComponent):
                         "path": self.path,
                     }
                 self.config.set(section, option, value)
-        return self.push(config.Save(), target=self.config)
+        return self.fire(config.Save(), self.config)
 
     def _load(self):
         # Create Config Component
         configfile = joinpath(self.path, "conf", "%s.ini" % self.envname)
         self.config = Config(configfile).register(self)
-        self.push(config.Load(), target=self.config)
+        self.fire(config.Load())
         return True
