@@ -7,23 +7,18 @@
 This package contains the essential core parts of the circuits framework.
 """
 
-from .handlers import handler
+from .handlers import handler, tick
 
-from .events import Event
 from .loader import Loader
 from .manager import Manager
 from .components import BaseComponent, Component
+from .events import BaseEvent, DerivedEvent, Event, LiteralEvent
 
 from .values import Value
 from .futures import future
 
 from .timers import Timer
 
-try:
-    from .bridge import Bridge
-except:
-     Bridge = None
-
 from .pools import Pool
 from .workers import Task, Worker
 from .debugger import Debugger
