@@ -20,37 +20,47 @@ from collections import defaultdict
 from circuits.net.sockets import Write
 from circuits import handler, BaseComponent, Event
 
-WEBSOCKETS_CHANNEL = "ws"
-
 
 class MalformedWebSocket(ValueError):
     """Malformed WebSocket Error"""
 
 
-class WebSocketEvent(Event):
-    """WebSocket Event"""
-
-    _target = WEBSOCKETS_CHANNEL
-
-
-class Message(WebSocketEvent):
+class Message(Event):
     """Message Event"""
 
-    target = WebSocketEvent._target
+
+class WebSocketsMediator(BaseComponent):
+
+    channel = "ws"
+
+    @handler("write")
+    def _on_write(self, sock, data):
+        payload = b'\x00' + data.encode("utf-8") + b'\xff'
+        self.fire(Write(sock, payload), self.parent.channel)
+
+    @handler("message_value_changed")
+    def _on_message_value_changed(self, value):
+        sock, message = value.event.args
+        result, data = value.result, value.value
+        if result and isinstance(data, basestring):
+                self.fire(Write(sock, data))
 
 
 class WebSockets(BaseComponent):
 
     channel = "web"
 
-    def __init__(self, path=None):
+    def __init__(self, path=None, wschannel="ws"):
         super(WebSockets, self).__init__()
 
         self.path = path
+        self.wschannel = wschannel
 
         self._clients = []
         self._buffers = defaultdict(bytes)
 
+        WebSocketsMediator(channel=wschannel).register(self)
+
     def _parse_messages(self, sock):
         msgs = []
         end_idx = 0
@@ -77,34 +87,21 @@ class WebSockets(BaseComponent):
         self._buffers[sock] = buf
         return msgs
 
-    @handler("disconnect", target="web")
+    @handler("disconnect")
     def _on_disconnect(self, sock):
         if sock in self._clients:
             self._clients.remove(sock)
         if sock in self._buffers:
             del self._buffers[sock]
 
-    @handler("write", target=WebSocketEvent._target)
-    def _on_write(self, sock, data):
-        payload = b'\x00' + data.encode("utf-8") + b'\xff'
-        self.push(Write(sock, payload))
-
-    @handler("value_changed", target=WebSocketEvent._target)
-    def _on_value_changed(self, value):
-        sock, message = value.event.args
-        result, data = value.result, value.value
-        if result and isinstance(data, basestring):
-                self.push(Write(sock, data),
-                        target=WebSocketEvent._target)
-
     @handler("read", filter=True)
     def _on_read(self, sock, data):
         if sock in self._clients:
             self._buffers[sock] += data
             messages = self._parse_messages(sock)
             for message in messages:
-                value = self.push(Message(sock, message))
-                value.onSet = "value_changed", WebSocketEvent._target
+                value = self.fire(Message(sock, message), self.wschannel)
+                value.notify = True
             return True
 
     @handler("request", filter=True, priority=0.2)
