@@ -25,21 +25,14 @@ class XMLRPC(BaseComponent):
 
     channel = "web"
 
-    def __init__(self, path=None, target="*", encoding="utf-8"):
+    def __init__(self, path=None, encoding="utf-8", rpc_channel="*"):
         super(XMLRPC, self).__init__()
 
         self.path = path
-        self.target = target
         self.encoding = encoding
+        self.rpc_channel = rpc_channel
 
-    @handler("value_changed", priority=0.1)
-    def _on_value_changed(self, value):
-        response = value.response
-        response.body = self._response(value.value)
-        self.push(Response(response), target=self.channel)
-        value.handled = True
-
-    @handler("request", filter=True, priority=0.1)
+    @handler("request", filter=True, priority=0.2)
     def _on_request(self, request, response):
         if self.path is not None and self.path != request.path.rstrip("/"):
             return
@@ -51,13 +44,25 @@ class XMLRPC(BaseComponent):
             params, method = loads(data)
 
             if "." in method:
-                t, c = method.split(".", 1)
+                channel, name = method.split(".", 1)
             else:
-                t, c = self.target, method
+                channel, name = self.rpc_channel, method
 
-            value = self.push(RPC(*params), c, t)
+            if not isinstance(name, bytes):
+                name = name.encode('utf-8')
+
+            @handler("%s_value_changed" % name, priority=0.1)
+            def _on_value_changed(self, value):
+                response = value.response
+                response.body = self._response(value.value)
+                self.fire(Response(response), self.channel)
+                value.handled = True
+
+            self.addHandler(_on_value_changed)
+
+            value = self.fire(RPC.create(name.title(), *params), channel)
             value.response = response
-            value.onSet = ("value_changed", self)
+            value.notify = True
         except Exception as e:
             r = self._error(1, "%s: %s" % (type(e), e))
             return r
