@@ -10,11 +10,12 @@ Note: This code is mostly borrowed from werkzeug and adapted for circuits.web
 """
 
 import sys
+from cgi import escape
 from inspect import isclass
 
-from .utils import escape
 from .constants import HTTP_STATUS_CODES
 
+
 class HTTPException(Exception):
     """
     Baseclass for all HTTP exceptions.  This exception can be called by WSGI
@@ -41,6 +42,7 @@ class HTTPException(Exception):
     def __repr__(self):
         return '<%s \'%s\'>' % (self.__class__.__name__, self)
 
+
 class BadRequest(HTTPException):
     """*400* `Bad Request`
 
@@ -53,12 +55,14 @@ class BadRequest(HTTPException):
         'not understand.</p>'
     )
 
+
 class UnicodeError(HTTPException):
     """
     raised by the request functions if they were unable to decode the
     incoming data properly.
     """
 
+
 class Unauthorized(HTTPException):
     """*401* `Unauthorized`
 
@@ -122,6 +126,7 @@ class MethodNotAllowed(HTTPException):
                     'for the requested URL.</p>'
                     ) % method
 
+
 class NotAcceptable(HTTPException):
     """*406* `Not Acceptable`
 
@@ -279,6 +284,7 @@ class ServiceUnavailable(HTTPException):
         'later.</p>'
     )
 
+
 class Redirect(HTTPException):
 
     code = 303
