@@ -23,10 +23,9 @@ from circuits.core import handler, BaseComponent, Value
 from . import wrappers
 from .utils import quoted_slash
 from .exceptions import HTTPException
-from .errors import HTTPError, NotFound
 from .headers import parse_headers, Headers
 from .events import Request, Response, Stream
-from .errors import Redirect as RedirectError
+from .errors import HTTPError, NotFound, Redirect
 from .exceptions import Redirect as RedirectException
 
 MAX_HEADER_FRAGENTS = 20
@@ -62,25 +61,25 @@ class HTTP(BaseComponent):
                 if response.chunked:
                     buf = [hex(len(data))[2:], b"\r\n", data, b"\r\n"]
                     data = b"".join(buf)
-                self.push(Write(response.request.sock, data))
+                self.fire(Write(response.request.sock, data))
             if response.body and not response.done:
                 try:
                     data = next(response.body)
                 except StopIteration:
                     data = None
-                self.push(Stream(response, data))
+                self.fire(Stream(response, data))
         else:
             if response.body:
                 response.body.close()
             if response.chunked:
-                self.push(Write(response.request.sock, b"0\r\n\r\n"))
+                self.fire(Write(response.request.sock, b"0\r\n\r\n"))
             if response.close:
-                self.push(Close(response.request.sock))
+                self.fire(Close(response.request.sock))
             response.done = True
 
     @handler("response")
     def _on_response(self, response):
-        self.push(
+        self.fire(
                 Write(response.request.sock,
                     str(response).encode(HTTP_ENCODING)))
 
@@ -89,28 +88,29 @@ class HTTP(BaseComponent):
                 data = next(response.body)
             except StopIteration:
                 data = None
-            self.push(Stream(response, data))
+            self.fire(Stream(response, data))
         else:
             if isinstance(response.body, bytes):
                 body = response.body
             elif isinstance(response.body, unicode):
                 body = response.body.encode(self._encoding)
             else:
-                parts = (s if isinstance(s, bytes) else s.encode(self._encoding) for s in response.body)
+                parts = (s if isinstance(s, bytes) else s.encode(self._encoding) \
+                    for s in response.body if s is not None)
                 body = b"".join(parts)
 
             if body:
                 if response.chunked:
                     buf = [hex(len(body))[2:].encode(), b"\r\n", body, b"\r\n"]
                     body = b"".join(buf)
-                self.push(Write(response.request.sock, body))
+                self.fire(Write(response.request.sock, body))
 
                 if response.chunked:
-                    self.push(Write(response.request.sock, b"0\r\n\r\n"))
+                    self.fire(Write(response.request.sock, b"0\r\n\r\n"))
 
             if not response.stream:
                 if response.close:
-                    self.push(Close(response.request.sock))
+                    self.fire(Close(response.request.sock))
                 response.done = True
 
     @handler("disconnect")
@@ -164,7 +164,7 @@ class HTTP(BaseComponent):
             self._clients[sock] = request, response
 
             if frag:
-                return self.push(HTTPError(request, response, 400))
+                return self.fire(HTTPError(request, response, 400))
 
             if params:
                 path = "%s;%s" % (path, params)
@@ -190,7 +190,7 @@ class HTTP(BaseComponent):
             # the client only understands 1.0. RFC 2616 10.5.6 says we should
             # only return 505 if the _major_ version is different.
             if not request.protocol[0] == request.server_protocol[0]:
-                return self.push(HTTPError(request, response, 505))
+                return self.fire(HTTPError(request, response, 505))
 
             rp = request.protocol
             sp = request.server_protocol
@@ -207,8 +207,8 @@ class HTTP(BaseComponent):
             request.body.write(data[(end_of_headers + 4):])
 
             if headers.get("Expect", "") == "100-continue":
-                return self.push(Response(wrappers.Response(request, 100),
-                    encoding=self._encoding))
+                return self.fire(Response(wrappers.Response(request, code=100,
+                    encoding=self._encoding)))
 
             contentLength = int(headers.get("Content-Length", "0"))
             if request.body.tell() < contentLength:
@@ -235,7 +235,7 @@ class HTTP(BaseComponent):
         else:
             req = Request(request, response)
 
-        self.push(req)
+        self.fire(req)
 
     @handler("httperror")
     def _on_httperror(self, event, request, response, code, **kwargs):
@@ -247,60 +247,84 @@ class HTTP(BaseComponent):
         """
 
         response.body = str(event)
-        self.push(Response(response))
+        self.fire(Response(response))
 
-    @handler("value_changed")
-    def _on_value_changed(self, value):
+    @handler("request_value_changed")
+    def _on_request_value_changed(self, value):
         if value.handled:
             return
         request, response = value.event.args[:2]
         if value.result and not value.errors:
             response.body = value.value
-            self.push(Response(response))
+            self.fire(Response(response))
         else:
             # This possibly never occurs.
-            self.push(HTTPError(request, response, error=value.value))
+            self.fire(HTTPError(request, response, error=value.value))
 
-    @handler("request_success", "request_filtered")
-    def _on_request_success_or_filtered(self, evt, handler, retval):
-        request, response = evt.args[:2]
+    @handler("request_success")
+    def _on_request_success(self, e, value):
+        # We only want the non-recursive value at this point.
+        # If the value is an instance of Value we will set
+        # the .notify flag and be notified of changes to the value.
+        value = e.value.getValue(recursive=False)
 
-        if not request.handled and retval is not None:
-            request.handled = True
-            if isinstance(retval, HTTPError):
-                self.push(retval)
-            elif isinstance(retval, wrappers.Response):
-                self.push(Response(retval))
-            elif isinstance(retval, Value):
-                if retval.result and not retval.errors:
-                    response.body = retval.value
-                    self.push(Response(response))
-                elif retval.errors:
-                    error = retval.value
-                    etype, evalue, traceback = error
-                    if isinstance(evalue, RedirectException):
-                        self.push(RedirectError(request, response,
-                            evalue.urls, evalue.status))
-                    elif isinstance(evalue, HTTPException):
-                        if evalue.traceback:
-                            self.push(HTTPError(request, response, evalue.code,
-                                description=evalue.description, error=error))
-                        else:
-                            self.push(HTTPError(request, response, evalue.code,
-                                description=evalue.description))
+        if isinstance(value, Value) and not value.promise:
+            value = value.getValue(recursive=False)
+
+        request, response = e.args[:2]
+
+        if value is None:
+            self.fire(NotFound(request, response))
+        elif isinstance(value, HTTPError):
+            response.body = str(value)
+            self.fire(Response(response))
+        elif isinstance(value, wrappers.Response):
+            self.fire(Response(value))
+        elif isinstance(value, Value):
+            if value.result and not value.errors:
+                response.body = value.value
+                self.fire(Response(response))
+            elif value.errors:
+                error = value.value
+                etype, evalue, traceback = error
+                if isinstance(evalue, RedirectException):
+                    self.fire(Redirect(request, response,
+                        evalue.urls, evalue.status))
+                elif isinstance(evalue, HTTPException):
+                    if evalue.traceback:
+                        self.fire(HTTPError(request, response, evalue.code,
+                            description=evalue.description, error=error))
                     else:
-                        self.push(HTTPError(request, response, error=error))
+                        self.fire(HTTPError(request, response, evalue.code,
+                            description=evalue.description))
                 else:
-                    if retval.manager is None:
-                        retval.manager = self
-                    retval.event = evt
-                    retval.onSet = "value_changed", self
-            elif type(retval) is not bool:
-                response.body = retval
-                self.push(Response(response))
+                    self.fire(HTTPError(request, response, error=error))
+            else:
+                # We want to be notified of changes to the value
+                value = e.value.getValue(recursive=False)
+                value.event = e
+                value.notify = True
+        elif type(value) is tuple:
+            etype, evalue, traceback = error = value
+
+            if isinstance(evalue, RedirectException):
+                self.fire(Redirect(request, response,
+                    evalue.urls, evalue.status))
+            elif isinstance(evalue, HTTPException):
+                if evalue.traceback:
+                    self.fire(HTTPError(request, response, evalue.code,
+                        description=evalue.description, error=error))
+                else:
+                    self.fire(HTTPError(request, response, evalue.code,
+                        description=evalue.description))
+            else:
+                self.fire(HTTPError(request, response, error=error))
+        elif type(value) is not bool:
+            response.body = value
+            self.fire(Response(response))
 
     @handler("request_failure", "response_failure")
-    def _on_request_or_response_failure(self, evt, handler, error):
+    def _on_request_or_response_failure(self, evt, err):
         if len(evt.args) == 1:
             response = evt.args[0]
             request = response.request
@@ -315,31 +339,17 @@ class HTTP(BaseComponent):
         if not request.handled:
             request.handled = True
 
-        etype, evalue, traceback = error
+        etype, evalue, traceback = err
 
         if isinstance(evalue, RedirectException):
-            self.push(RedirectError(request, response,
+            self.fire(Redirect(request, response,
                 evalue.urls, evalue.status))
         elif isinstance(evalue, HTTPException):
             if evalue.traceback:
-                self.push(HTTPError(request, response, evalue.code,
-                    description=evalue.description, error=error))
+                self.fire(HTTPError(request, response, evalue.code,
+                    description=evalue.description, error=err))
             else:
-                self.push(HTTPError(request, response, evalue.code,
+                self.fire(HTTPError(request, response, evalue.code,
                     description=evalue.description))
         else:
-            self.push(HTTPError(request, response, error=error))
-
-    @handler("request_completed")
-    def _on_request_completed(self, evt, handler, retval):
-        request, response = evt.args[:2]
-
-        # Return a 404 response on any of the following:
-        # 1) The request was not successful (request.handled)
-        # 2) The request was not handled by any handler (handler)
-        # 3) The value is both None and is not a future.
-        #    (evt.value.value, evt.future)
-
-        if not request.handled or handler is None or \
-                (evt.value.value is None and not evt.future):
-            self.push(NotFound(request, response))
+            self.fire(HTTPError(request, response, error=err))
