@@ -23,19 +23,19 @@ try:
 except ImportError:
     psyco = None
 
-from circuits.net.pollers import Select
+from circuits.core.pollers import Select
 from circuits.tools import inspect, graph
 from circuits import Component, Manager, Debugger
 from circuits import __version__ as systemVersion
 from circuits.web import BaseServer, Server, Controller, Static, wsgi
 
 try:
-    from circuits.net.pollers import Poll
+    from circuits.core.pollers import Poll
 except ImportError:
     Poll = None
 
 try:
-    from circuits.net.pollers import EPoll
+    from circuits.core.pollers import EPoll
 except ImportError:
     EPoll = None
 
@@ -47,6 +47,7 @@ VERSION = "%prog v" + systemVersion
 ### Functions
 ###
 
+
 def parse_options():
     """parse_options() -> opts, args
 
@@ -96,6 +97,7 @@ def parse_options():
 ### Components
 ###
 
+
 class HelloWorld(Component):
 
     channel = "web"
@@ -103,6 +105,7 @@ class HelloWorld(Component):
     def request(self, request, response):
         return "Hello World!"
 
+
 class Root(Controller):
 
     def hello(self):
@@ -112,6 +115,7 @@ class Root(Controller):
 ### Main
 ###
 
+
 def main():
     opts, args = parse_options()
 
@@ -132,7 +136,7 @@ def main():
 
         httpd = make_server(address, port, app)
         httpd.serve_forever()
-        
+
         raise SystemExit(0)
 
     manager = Manager()
