@@ -9,9 +9,9 @@ class Cat(File):
     stdout = stdout
 
     def read(self, data):
-        self.fire(Write(data), target=stdout)
+        self.fire(Write(data), stdout)
 
     def eof(self):
-        raise SystemExit, 0
+        raise SystemExit(0)
 
 Cat(sys.argv[1]).run()
