@@ -19,7 +19,7 @@ def restore_tty_settings(fd):
 class Echo(Component):
 
     def read(self, data):
-        if data.lower() == "q":
+        if data.lower() in "q":
             raise SystemExit, 0
         else:
             sys.stdout.write(data)
