@@ -1,14 +1,15 @@
 #!/usr/bin/env python
 
-from circuits import Component
+from circuits import handler, Component
 from circuits.web import Server, Controller
 
 class Upper(Component):
 
-    channel = "http"
+    channel = "web"
 
-    def response(self, response):
-        response.body = response.body.upper()
+    @handler("response", priority=1.0)
+    def _on_response(self, response):
+        response.body = "".join(response.body).upper()
 
 class Root(Controller):
 
