@@ -3,7 +3,11 @@
 import os
 import sys
 
-from coverage import coverage
+try:
+    from coverage import coverage
+    HAS_COVERAGE = True
+except ImportError:
+    HAS_COVERAGE = False
 
 from circuits import Component
 from circuits.app import Daemon
@@ -16,15 +20,17 @@ class App(Component):
         Daemon(pidfile).register(self)
 
 def main():
-    _coverage = coverage(data_suffix=True)
-    _coverage.start()
+    if HAS_COVERAGE:
+        _coverage = coverage(data_suffix=True)
+        _coverage.start()
 
     pidfile = os.path.abspath(sys.argv[1])
     app = App(pidfile)
     app.run()
 
-    _coverage.stop()
-    _coverage.save()
+    if HAS_COVERAGE:
+        _coverage.stop()
+        _coverage.save()
 
 if __name__ == "__main__":
     main()
