@@ -23,12 +23,26 @@ def test_repr():
     e = Test()
 
     s = repr(e)
-    assert s == "<Test[] [] {}>"
+    assert s == "<Test[.test] ( )>"
 
-    app.push(e)
+    app.fire(e)
 
     s = repr(e)
-    assert s == "<Test[*:test] [] {}>"
+    assert s == "<Test[*.test] ( )>"
+
+def test_create():
+    app = App()
+    while app: app.flush()
+
+    e = Event.create("Test")
+
+    s = repr(e)
+    assert s == "<Test[.test] ( )>"
+
+    app.fire(e)
+
+    s = repr(e)
+    assert s == "<Test[*.test] ( )>"
 
 def test_getitem():
     app = App()
