@@ -24,20 +24,21 @@ def test_return_generator():
     app = App()
     while app: app.flush()
 
-    v = app.push(Test())
-    app.flush()
+    v = app.fire(Test())
+    app.tick()
+    app.tick()
 
-    g = v.value
-    s = next(g)
-    assert s == "Hello"
+    x = v.value
+    assert x == "Hello"
 
 def test_yield():
     app = App()
     while app: app.flush()
 
-    v = app.push(Hello())
-    app.flush()
+    v = app.fire(Hello())
+    app.tick()
+    app.tick()
+    app.tick()
 
-    g = v.value
-    s = "".join(g)
-    assert s == "Hello World!"
+    x = v.value
+    assert x == ["Hello ", "World!"]
