@@ -14,6 +14,7 @@ class Base(Component):
 
 class App1(Base):
 
+    @handler("test", priority=-1)
     def test(self):
         return "Foobar"
 
@@ -27,7 +28,7 @@ def test_inheritence():
     app = App1()
     app.start()
 
-    x = app.push(Test())
+    x = app.fire(Test())
     assert pytest.wait_for(x, "result")
     v = x.value
     assert v == ["Hello World!", "Foobar"]
@@ -38,7 +39,7 @@ def test_override():
     app = App2()
     app.start()
 
-    x = app.push(Test())
+    x = app.fire(Test())
     assert pytest.wait_for(x, "result")
     v = x.value
     assert v == "Foobar"
