@@ -1,11 +1,10 @@
 #!/usr/bin/env python
 
 import os
+import sys
 
-import pytest
-pytest.importorskip("pytest_cov")
 
-def test(tmpdir, cov):
+def test(tmpdir):
     if not os.name == "posix":
         py.test.skip("Cannot run test on a non-POSIX platform.")
 
@@ -20,13 +19,15 @@ def test(tmpdir, cov):
     pidfile = str(tmpdir.join(".pid"))
     signalfile = str(tmpdir.join(".signal"))
 
-    args = ["python", signalapp.__file__, pidfile, signalfile]
+    args = [sys.executable, signalapp.__file__, pidfile, signalfile]
     cmd = " ".join(args)
-    p = Popen(cmd, shell=True)
+    p = Popen(cmd, shell=True, env={'PYTHONPATH': ':'.join(sys.path)})
     status = p.wait()
 
     assert status == 0
 
+    sleep(1)
+
     assert os.path.exists(pidfile)
     assert os.path.isfile(pidfile)
 
@@ -34,19 +35,14 @@ def test(tmpdir, cov):
     pid = int(f.read().strip())
     f.close()
 
-    os.kill(pid, SIGHUP)
+    os.kill(pid, SIGTERM)
     sleep(1)
 
     f = open(signalfile, "r")
     signal = f.read().strip()
     f.close()
 
-    assert signal == str(SIGHUP)
-
-    os.kill(pid, SIGTERM)
-    assert True
+    assert signal == str(SIGTERM)
 
     os.remove(pidfile)
     os.remove(signalfile)
-
-    cov.combine()
