@@ -3,7 +3,7 @@
 import pytest
 
 from circuits import Manager
-from circuits.core.utils import itercmp
+from circuits.core.utils import findtype
 from circuits.core.pollers import BasePoller, Poller
 from circuits.net.sockets import TCPServer, TCPClient
 
@@ -18,7 +18,7 @@ def test():
     m.start()
 
     try:
-        pollers = list(itercmp(m, BasePoller, subclass=False))
+        pollers = findtype(m, BasePoller, all=True)
         assert len(pollers) == 1
         assert pollers[0] is poller
     finally:
