@@ -6,6 +6,9 @@
 
 import os
 
+import pytest
+
+
 DOCROOT = os.path.join(os.path.dirname(__file__), "static")
 
 
@@ -42,11 +45,15 @@ def setupwebapp(request):
     from circuits.web import Static
 
     Static("/static", DOCROOT, dirlisting=True).register(webapp)
+    waiter = pytest.WaitEvent(webapp, "ready")
     webapp.start()
+
+    assert waiter.wait()
+
     return webapp
 
 
 def teardownwebapp(webapp):
     from circuits.net.sockets import Close
-    webapp.push(Close(), target=webapp.server)
+    webapp.fire(Close(), webapp.server)
     webapp.stop()
