@@ -1,9 +1,8 @@
-#!/usr/bin/env python
-
-from urllib2 import urlopen, HTTPError
-
 from circuits.web import expose, Controller
 
+from .helpers import urlopen, HTTPError
+
+
 class Root(Controller):
 
     def index(self):
@@ -20,16 +19,16 @@ class Root(Controller):
 def test(webapp):
     f = urlopen(webapp.server.base)
     s = f.read()
-    assert s == "Hello World!"
+    assert s == b"Hello World!"
 
     f = urlopen("%s/+test" % webapp.server.base)
     s = f.read()
-    assert s == "test"
+    assert s == b"test"
 
     f = urlopen("%s/foo+bar" % webapp.server.base)
     s = f.read()
-    assert s == "foobar"
+    assert s == b"foobar"
 
     f = urlopen("%s/foo_bar" % webapp.server.base)
     s = f.read()
-    assert s == "foobar"
+    assert s == b"foobar"
