@@ -18,7 +18,7 @@ class Root(Controller):
 
     @future()
     def index(self):
-        return self.push(Hello())
+        return self.fire(Hello())
 
 def test(webapp):
     Test().register(webapp)
