@@ -1,17 +1,16 @@
 #!/usr/bin/env python
 
-from urllib2 import urlopen
-
-import pytest
-
 try:
-    from jsonrpclib import ServerProxy
+    from urllib.request import urlopen
 except ImportError:
-    pytest.skip("Skip: No JSON support")
+    from urllib2 import urlopen
 
 from circuits import Component
 from circuits.web import Controller, JSONRPC
 
+from .jsonrpclib import ServerProxy
+from .helpers import urlopen
+
 class Test(Component):
 
     def eval(self, s):
@@ -30,10 +29,10 @@ def test(webapp):
 
     f = urlopen(webapp.server.base)
     s = f.read()
-    assert s == "Hello World!"
+    assert s == b"Hello World!"
 
     url = "%s/rpc/" % webapp.server.base
-    jsonrpc = ServerProxy(url, allow_none=True)
+    jsonrpc = ServerProxy(url, allow_none=True, encoding='utf-8')
 
     data = jsonrpc.eval("1 + 2")
     assert data["result"] == 3
