@@ -1,9 +1,7 @@
-#!/usr/bin/env python
-
-from urllib2 import urlopen, HTTPError
-
 from circuits.web import Controller
 
+from .helpers import urlopen, HTTPError
+
 class Root(Controller):
 
     def index(self):
@@ -12,7 +10,7 @@ class Root(Controller):
 def test(webapp):
     try:
         urlopen(webapp.server.base)
-    except HTTPError, e:
+    except HTTPError as e:
         assert e.code == 404
         assert e.msg == "Not Found"
     else:
