@@ -11,13 +11,13 @@ from .helpers import urlopen
 
 class Root(Controller):
 
-    @handler("started", priority=1.0, target="*")
-    def _on_started(self, component, mode):
+    @handler("started", priority=1.0, channel="*")
+    def _on_started(self, component):
         fd, self.filename = mkstemp()
         os.write(fd, b"Hello World!")
         os.close(fd)
 
-    @handler("stopped", target="(")
+    @handler("stopped", channel="(")
     def _on_stopped(self, component):
         os.remove(self.filename)
 
