@@ -1,16 +1,14 @@
 #!/usr/bin/env python
 
 from os.path import basename
-from urllib2 import urlopen, URLError
 from socket import gaierror
 
-import pytest
-pytest.skip()
-
 from circuits import Component
 from circuits.web import Controller
 from circuits.web import BaseServer, Server
 
+from .helpers import urlopen, URLError
+
 class BaseRoot(Component):
 
     channel = "web"
@@ -18,11 +16,13 @@ class BaseRoot(Component):
     def request(self, request, response):
         return "Hello World!"
 
+
 class Root(Controller):
 
     def index(self):
         return "Hello World!"
 
+
 def test_baseserver():
     server = BaseServer(0)
     BaseRoot().register(server)
@@ -30,14 +30,15 @@ def test_baseserver():
 
     try:
         f = urlopen(server.base)
-    except URLError, e:
+    except URLError as e:
         if type(e[0]) is gaierror:
             f = urlopen("http://127.0.0.1:9000")
         else:
             raise
 
     s = f.read()
-    assert s == "Hello World!"
+    assert s == b"Hello World!"
+
 
 def test_server():
     server = Server(0)
@@ -46,14 +47,15 @@ def test_server():
 
     try:
         f = urlopen(server.base)
-    except URLError, e:
+    except URLError as e:
         if type(e[0]) is gaierror:
             f = urlopen("http://127.0.0.1:9000")
         else:
             raise
 
     s = f.read()
-    assert s == "Hello World!"
+    assert s == b"Hello World!"
+
 
 def test_unixserver(tmpdir):
     sockpath = tmpdir.ensure("test.sock")
