@@ -17,7 +17,7 @@ class Test1(Component):
     channel = "ws"
 
     def message(self, sock, data):
-        self.push(Write(sock, data))
+        self.fire(Write(sock, data))
 
 
 class Test2(Component):
