@@ -1,6 +1,7 @@
 #!/usr/bin/env python
 
-from urllib2 import urlopen
+from .helpers import urlopen
+
 
 def application(environ, start_response):
     status = "200 OK"
@@ -12,4 +13,4 @@ def application(environ, start_response):
 def test(webapp):
     f = urlopen(webapp.server.base)
     s = f.read()
-    assert s == "Hello World!"
+    assert s == b"Hello World!"
