@@ -1,9 +1,10 @@
 #!/usr/bin/env python
 
-from urllib2 import urlopen
-
 from circuits.web import Controller
 
+from .helpers import urlopen
+
+
 class Root(Controller):
 
     def index(self):
@@ -13,4 +14,4 @@ class Root(Controller):
 def test(webapp):
     f = urlopen(webapp.server.base)
     s = f.read()
-    assert s == "Hello World!"
+    assert s == b"Hello World!"
